@@ -4,8 +4,8 @@
  */
 import { getInjectable } from "@ogre-tools/injectable";
 import { computed } from "mobx";
-import type { Route } from "../../../../route-injection-token";
-import { routeInjectionToken } from "../../../../route-injection-token";
+import type { Route } from "../../../../front-end-route-injection-token";
+import { frontEndRouteInjectionToken } from "../../../../front-end-route-injection-token";
 
 export interface PortForwardsPathParameters {
   forwardport?: string;
@@ -20,7 +20,7 @@ const portForwardsRouteInjectable = getInjectable({
     isEnabled: computed(() => true),
   }),
 
-  injectionToken: routeInjectionToken,
+  injectionToken: frontEndRouteInjectionToken,
 });
 
 export default portForwardsRouteInjectable;
