@@ -3,8 +3,6 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import { ipcMain } from "electron";
-import userStoreFileNameMigrationInjectable from "./file-name-migration.injectable";
 import { UserStore } from "./user-store";
 import selectedUpdateChannelInjectable from "../application-update/selected-update-channel/selected-update-channel.injectable";
 
@@ -14,10 +12,6 @@ const userStoreInjectable = getInjectable({
   instantiate: (di) => {
     UserStore.resetInstance();
 
-    if (ipcMain) {
-      di.inject(userStoreFileNameMigrationInjectable);
-    }
-
     return UserStore.createInstance({
       selectedUpdateChannel: di.inject(selectedUpdateChannelInjectable),
     });
