@@ -3,12 +3,16 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import { isWindows } from "../vars";
+import platformInjectable from "./platform.injectable";
 
 const isWindowsInjectable = getInjectable({
   id: "is-windows",
-  instantiate: () => isWindows,
-  causesSideEffects: true,
+
+  instantiate: (di) => {
+    const platform = di.inject(platformInjectable);
+
+    return platform === "win32";
+  },
 });
 
 export default isWindowsInjectable;
