@@ -8,13 +8,15 @@ import * as path from "path";
 import type { LensExtension } from "./lens-extension";
 import assert from "assert";
 
-export abstract class ExtensionStore<T> extends BaseStore<T> {
+export abstract class ExtensionStore<T extends object> extends BaseStore<T> {
   readonly displayName = "ExtensionStore<T>";
   protected extension?: LensExtension;
 
   loadExtension(extension: LensExtension) {
     this.extension = extension;
 
+    this.params.projectVersion ??= this.extension.version;
+
     return super.load();
   }
 
