@@ -7,6 +7,8 @@ import extensionLoaderInjectable from "../../../extensions/extension-loader/exte
 import { LensProtocolRouterMain } from "./lens-protocol-router-main";
 import extensionsStoreInjectable from "../../../extensions/extensions-store/extensions-store.injectable";
 import showApplicationWindowInjectable from "../../start-main-application/lens-window/show-application-window.injectable";
+import broadcastMessageInjectable from "../../../common/ipc/broadcast-message.injectable";
+import loggerInjectable from "../../../common/logger.injectable";
 
 const lensProtocolRouterMainInjectable = getInjectable({
   id: "lens-protocol-router-main",
@@ -16,6 +18,8 @@ const lensProtocolRouterMainInjectable = getInjectable({
       extensionLoader: di.inject(extensionLoaderInjectable),
       extensionsStore: di.inject(extensionsStoreInjectable),
       showApplicationWindow: di.inject(showApplicationWindowInjectable),
+      broadcastMessage: di.inject(broadcastMessageInjectable),
+      logger: di.inject(loggerInjectable),
     }),
 });
 
