@@ -10,7 +10,7 @@ import extensionInstallationStateStoreInjectable
   from "../../../../extensions/extension-installation-state-store/extension-installation-state-store.injectable";
 
 const installFromInputInjectable = getInjectable({
-  id: "install-from-input",
+  id: "install-extension-from-input",
 
   instantiate: (di) =>
     installFromInput({
