@@ -3,21 +3,20 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import type {
-  IReleaseCreatePayload } from "../../../../common/k8s-api/endpoints/helm-releases.api";
-import {
-  createRelease,
-} from "../../../../common/k8s-api/endpoints/helm-releases.api";
+
 import releasesInjectable from "../releases.injectable";
+import type { CallForCreateHelmRelease } from "./call-for-create-helm-release.injectable";
+import callForCreateHelmReleaseInjectable from "./call-for-create-helm-release.injectable";
 
 const createReleaseInjectable = getInjectable({
   id: "create-release",
 
-  instantiate: (di) => {
+  instantiate: (di): CallForCreateHelmRelease => {
     const releases = di.inject(releasesInjectable);
+    const callForCreateRelease = di.inject(callForCreateHelmReleaseInjectable);
 
-    return async (payload: IReleaseCreatePayload) => {
-      const release = await createRelease(payload);
+    return async (payload) => {
+      const release = await callForCreateRelease(payload);
 
       releases.invalidate();
 
