@@ -3,27 +3,20 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 
-import "./controls.scss";
+import styles from "./controls.module.scss";
 
-import React from "react";
 import { observer } from "mobx-react";
+import React from "react";
 
-import { cssNames } from "../../../utils";
 import { Checkbox } from "../../checkbox";
-import { Icon } from "../../icon";
+import { DownloadLogsDropdown } from "./download-logs-dropdown";
 import type { LogTabViewModel } from "./logs-view-model";
-import { withInjectables } from "@ogre-tools/injectable-react";
-import openSaveFileDialogInjectable from "../../../utils/save-file.injectable";
 
 export interface LogControlsProps {
   model: LogTabViewModel;
 }
 
-interface Dependencies {
-  openSaveFileDialog: (filename: string, contents: BlobPart | BlobPart[], type: string) => void;
-}
-
-const NonInjectedLogControls = observer(({ openSaveFileDialog, model }: Dependencies & LogControlsProps) => {
+export const LogControls = observer(({ model }: LogControlsProps) => {
   const tabData = model.logTabData.get();
   const pod = model.pod.get();
 
@@ -44,18 +37,9 @@ const NonInjectedLogControls = observer(({ openSaveFileDialog, model }: Dependen
     model.reloadLogs();
   };
 
-  const downloadLogs = () => {
-    const fileName = pod.getName();
-    const logsToDownload: string[] = showTimestamps
-      ? model.logs.get()
-      : model.logsWithoutTimestamps.get();
-
-    openSaveFileDialog(`${fileName}.log`, logsToDownload.join("\n"), "text/plain");
-  };
-
   return (
-    <div className={cssNames("LogControls flex gaps align-center justify-space-between wrap")}>
-      <div className="time-range">
+    <div className={styles.controls} data-testid="log-controls">
+      <div>
         {since && (
           <span>
             Logs from
@@ -77,20 +61,13 @@ const NonInjectedLogControls = observer(({ openSaveFileDialog, model }: Dependen
           onChange={togglePrevious}
           className="show-previous"
         />
-        <Icon
-          material="get_app"
-          onClick={downloadLogs}
-          tooltip="Download"
-          className="download-icon"
+
+        <DownloadLogsDropdown
+          downloadVisibleLogs={model.downloadLogs}
+          downloadAllLogs={model.downloadAllLogs}
         />
       </div>
     </div>
   );
 });
 
-export const LogControls = withInjectables<Dependencies, LogControlsProps>(NonInjectedLogControls, {
-  getProps: (di, props) => ({
-    openSaveFileDialog: di.inject(openSaveFileDialogInjectable),
-    ...props,
-  }),
-});
