@@ -3,7 +3,6 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import type { TerminalApi } from "../../../api/terminal-api";
 import type { TabId } from "../dock/store";
 import terminalStoreInjectable from "./store.injectable";
 
@@ -13,7 +12,7 @@ const getTerminalApiInjectable = getInjectable({
   instantiate: (di) => {
     const terminalStore = di.inject(terminalStoreInjectable);
 
-    return (tabId: TabId): TerminalApi => terminalStore.getTerminalApi(tabId);
+    return (tabId: TabId) => terminalStore.getTerminalApi(tabId);
   },
 });
 
