@@ -5,12 +5,14 @@
 import { getInjectable } from "@ogre-tools/injectable";
 import { TerminalStore } from "./store";
 import createTerminalInjectable from "./create-terminal.injectable";
+import createTerminalApiInjectable from "../../../api/create-terminal-api.injectable";
 
 const terminalStoreInjectable = getInjectable({
   id: "terminal-store",
 
   instantiate: (di) => new TerminalStore({
     createTerminal: di.inject(createTerminalInjectable),
+    createTerminalApi: di.inject(createTerminalApiInjectable),
   }),
 });
 
